@@ -3,7 +3,7 @@
 '''
 A library to access Tryton's models like a client.
 '''
-__version__ = "2.6.4"
+__version__ = "2.8.1"
 __all__ = ['Model', 'Wizard']
 import sys
 try:
@@ -186,6 +186,12 @@ class TimeDescriptor(FieldDescriptor):
         super(TimeDescriptor, self).__set__(instance, value)
 
 
+class DictDescriptor(FieldDescriptor):
+    def __set__(self, instance, value):
+        assert isinstance(value, dict) or value in (None, False)
+        super(DictDescriptor, self).__set__(instance, value)
+
+
 class Many2OneDescriptor(FieldDescriptor):
     def __get__(self, instance, owner):
         relation = Model.get(self.definition['relation'], instance._config)
@@ -269,6 +275,7 @@ class One2ManyValueDescriptor(ValueDescriptor):
         value = [('add', [])]
         value_list = getattr(instance, self.name)
         parent_name = self.definition.get('relation_field', '')
+        to_create = []
         for record in value_list:
             if record.id >= 0:
                 values = record._get_values(fields=record._changed)
@@ -279,7 +286,9 @@ class One2ManyValueDescriptor(ValueDescriptor):
             else:
                 values = record._get_values()
                 values.pop(parent_name, None)
-                value.append(('create', values))
+                to_create.append(values)
+        if to_create:
+            value.append(('create', to_create))
         if value_list.record_removed:
             value.append(('unlink', [x.id for x in value_list.record_removed]))
         if value_list.record_deleted:
@@ -347,6 +356,7 @@ class MetaModelFactory(object):
         'date': DateDescriptor,
         'datetime': DateTimeDescriptor,
         'time': TimeDescriptor,
+        'dict': DictDescriptor,
         'many2one': Many2OneDescriptor,
         'one2many': One2ManyDescriptor,
         'many2many': Many2ManyDescriptor,
@@ -653,7 +663,7 @@ class Model(object):
         context = self._config.context
         if self.id < 0:
             values = self._get_values()
-            self.__id = self._proxy.create(values, context)
+            self.__id, = self._proxy.create([values], context)
         else:
             if not self._changed:
                 return
@@ -760,7 +770,7 @@ class Model(object):
         values = self._get_on_change_value()
         if self._parent:
             values['_parent_%s' % self._parent_name] = \
-                    _EvalEnvironment(self._parent)
+                _EvalEnvironment(self._parent)
         for arg in args:
             scope = values
             for i in arg.split('.'):
@@ -783,7 +793,7 @@ class Model(object):
             for record in to_remove:
                 # remove without signal
                 list.remove(getattr(self, field), record)
-            if value and (value.get('add') or value.get('update')):
+            if value and value.get('add') or value.get('update'):
                 for vals in value.get('add', []):
                     relation = Model.get(self._fields[field]['relation'],
                             self._config)
